@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: lib.c,v 2.0 1998/12/12 08:06:35 roessler Rel $";
+static const char rcsid[]="$Id: lib.c,v 2.2 1999/01/02 09:11:35 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -339,8 +339,9 @@ char *safe_strdup (const char *s)
   char *p;
   size_t l;
 
-  if (!s || !*s) return 0;
-  l = mutt_strlen (s) + 1;
+  if (!s || !*s)
+    return 0;
+  l = strlen (s) + 1;
   p = (char *)safe_malloc (l);
   memcpy (p, s, l);
   return (p);
@@ -674,9 +675,25 @@ int safe_symlink(const char *oldpath, const char *newpath)
   if(unlink(newpath) == -1 && errno != ENOENT)
     return -1;
   
-  if(symlink(oldpath, newpath) == -1)
+  if (oldpath[0] == '/')
+  {
+    if (symlink (oldpath, newpath) == -1)
+      return -1;
+  }
+  else
+  {
+    char abs_oldpath[_POSIX_PATH_MAX];
+
+    if ((getcwd (abs_oldpath, sizeof abs_oldpath) == NULL) ||
+	(strlen (abs_oldpath) + 1 + strlen (oldpath) + 1 > sizeof abs_oldpath))
     return -1;
   
+    strcat (abs_oldpath, "/");
+    strcat (abs_oldpath, oldpath);
+    if (symlink (abs_oldpath, newpath) == -1)
+      return -1;
+  }
+
   if(stat(oldpath, &osb) == -1 || stat(newpath, &nsb) == -1
      || compare_stat(&osb, &nsb) == -1)
   {
@@ -1267,5 +1284,5 @@ int mutt_strncasecmp(const char *a, const char *b, size_t l)
 
 size_t mutt_strlen(const char *a)
 {
-  return strlen(NONULL(a));
+  return a ? strlen (a) : 0;
 }
