@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: main.c,v 2.0 1998/12/12 08:06:37 roessler Rel $";
+static const char rcsid[]="$Id: main.c,v 2.1 1998/12/30 07:58:38 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -115,7 +115,7 @@ static void show_version (void)
   struct utsname uts;
 
   printf ("Mutt %s (%s)\n", MUTT_VERSION, ReleaseDate);
-  puts (Notice);
+  puts (_(Notice));
 
   uname (&uts);
 
@@ -133,7 +133,7 @@ static void show_version (void)
   printf (" [using slang %d]", SLANG_VERSION);
 #endif
 
-  puts ("\nCompile options:");
+  puts (_("\nCompile options:"));
 
 #ifdef DOMAIN
   printf ("DOMAIN=\"%s\"\n", DOMAIN);
@@ -245,7 +245,7 @@ static void show_version (void)
 
 
 
-  puts(ReachingUs);
+  puts(_(ReachingUs));
 
   exit (0);
 }
@@ -434,8 +434,8 @@ int main (int argc, char **argv)
       break;
     default:
       printf ("Mutt %s (%s)\n", MUTT_VERSION, ReleaseDate);
-      puts (Copyright);
-      puts (ReachingUs);
+      puts (_(Copyright));
+      puts (_(ReachingUs));
       exit (0);
   }
 
