@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: send.c,v 2.0 1998/12/12 08:07:22 roessler Rel $";
+static const char rcsid[]="$Id: send.c,v 2.1 1999/01/04 12:52:19 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -1151,8 +1151,16 @@ main_loop:
 
   if (send_message (msg) == -1)
   {
-    msg->content = mutt_remove_multipart (msg->content);
-    goto main_loop;
+    if (!(flags & SENDBATCH))
+    {
+      msg->content = mutt_remove_multipart (msg->content);
+      goto main_loop;
+    }
+    else
+    {
+      puts _("Could not send the message.");
+      goto cleanup;
+    }
   }
 
   if (!option (OPTNOCURSES) && ! (flags & SENDMAILX))
